@@ -217,7 +217,71 @@ def label_create_split(args, data_dir):
     print('data split complete')
 
 
+# def data_aug(aug_file, data_dir):
+#     """
+#     数据集新切分，后增强
+#     只对 trainval.txt 部分增强
+#     Args:
+#         aug_file:
+#         data_dir:
+#
+#     Returns:
+#
+#     """
+#     config_dict, methods = get_methods_from_yml(aug_file)
+#
+#     t1 = time.time()
+#     if not os.path.exists(data_dir):
+#         raise FileNotFoundError('未能找到相应文件夹，请核查传入的路径')
+#     IMG_DIR = data_dir + os.sep + "JPEGImages"
+#     XML_DIR = data_dir + os.sep + "Annotations"
+#     reset_dir(IMG_DIR)
+#     reset_dir(XML_DIR)
+#
+#     imgfiles = os.listdir(IMG_DIR)
+#     if not config_dict["basic"]["thread_num"]:
+#         aug_act(config_dict, XML_DIR, IMG_DIR, imgfiles, methods)  # 未采用多线程
+#     else:
+#         threading_treat(config_dict, XML_DIR, IMG_DIR, imgfiles, methods)
+#     if config_dict["basic"]["split"]:
+#         label_create_split(config_dict, data_dir)
+#
+#     # 生成新的trainval.txt
+#     voc_txt_dir = os.path.join(data_dir, "ImageSets", "Main")
+#     if os.path.exists(voc_txt_dir):
+#         for voc_txt in os.listdir(voc_txt_dir):
+#             rm_path = os.path.join(voc_txt_dir, voc_txt)
+#             if os.path.isfile(rm_path):
+#                 os.remove(rm_path)
+#     else:
+#         os.makedirs(voc_txt_dir, exist_ok=True)
+#     txt_path = os.path.join(voc_txt_dir, "trainval.txt")
+#     xml_names = []
+#     for root, _, files in os.walk(XML_DIR):
+#         for xml_file in files:
+#             xml_name = os.path.splitext(xml_file)[0]
+#             xml_names.append(xml_name)
+#     with open(txt_path, "w", encoding="utf-8") as fw:
+#         for item in xml_names:
+#             item = item.replace("\n", "").replace("\r\n", "")
+#             fw.write(item)
+#             fw.write("\n")
+#
+#     print('time cost : %sS' % round(time.time() - t1, 2))
+
+
 def data_aug(aug_file, data_dir):
+    """
+    数据集新切分，后增强
+    切分后，Main 文件中必含有 trainval.txt
+    只对 trainval.txt 部分增强
+    Args:
+        aug_file:
+        data_dir:
+
+    Returns:
+
+    """
     config_dict, methods = get_methods_from_yml(aug_file)
 
     t1 = time.time()
@@ -228,34 +292,54 @@ def data_aug(aug_file, data_dir):
     reset_dir(IMG_DIR)
     reset_dir(XML_DIR)
 
-    imgfiles = os.listdir(IMG_DIR)
+    voc_txt_dir = os.path.join(data_dir, "ImageSets", "Main")
+    trainval_txt_path = os.path.join(voc_txt_dir, "trainval.txt")
+    test_txt_path = os.path.join(voc_txt_dir, "test.txt")
+
+    # rest trainval.txt
+    with open(trainval_txt_path, "r", encoding="utf-8") as fr:
+        xml_trainval_reset = fr.readlines()
+    with open(trainval_txt_path, "w", encoding="utf-8") as fw:
+        for item in xml_trainval_reset:
+            if not item.strip().startswith("imgaug_"):
+                item = item.replace("\n", "").replace("\r\n", "")
+                fw.write(item)
+                fw.write("\n")
+
+    # 读取原始 trainval.txt
+    with open(trainval_txt_path, "r", encoding="utf-8") as fr:
+        xml_trainval_ori = fr.readlines()
+        xml_trainval_ori = [item.strip() for item in xml_trainval_ori]
+    with open(test_txt_path, "r", encoding="utf-8") as fr:
+        xml_test_ori = fr.readlines()
+        xml_test_ori = [item.strip() for item in xml_test_ori]
+
+    # 只有 trainval.txt 中的图片参与增强
+    imgfiles_all = os.listdir(IMG_DIR)
+    imgfiles = []
+    for item in imgfiles_all:
+        if item.split(".")[0] in xml_trainval_ori:
+            imgfiles.append(item)
+
     if not config_dict["basic"]["thread_num"]:
         aug_act(config_dict, XML_DIR, IMG_DIR, imgfiles, methods)  # 未采用多线程
     else:
         threading_treat(config_dict, XML_DIR, IMG_DIR, imgfiles, methods)
-    if config_dict["basic"]["split"]:
-        label_create_split(config_dict, data_dir)
+    # if config_dict["basic"]["split"]:
+    #     label_create_split(config_dict, data_dir)
 
     # 生成新的trainval.txt
-    voc_txt_dir = os.path.join(data_dir, "ImageSets", "Main")
-    if os.path.exists(voc_txt_dir):
-        for voc_txt in os.listdir(voc_txt_dir):
-            rm_path = os.path.join(voc_txt_dir, voc_txt)
-            if os.path.isfile(rm_path):
-                os.remove(rm_path)
-    else:
-        os.makedirs(voc_txt_dir, exist_ok=True)
-    txt_path = os.path.join(voc_txt_dir, "trainval.txt")
     xml_names = []
     for root, _, files in os.walk(XML_DIR):
         for xml_file in files:
             xml_name = os.path.splitext(xml_file)[0]
             xml_names.append(xml_name)
-    with open(txt_path, "w", encoding="utf-8") as fw:
+    with open(trainval_txt_path, "a+", encoding="utf-8") as fw:
         for item in xml_names:
-            item = item.replace("\n", "").replace("\r\n", "")
-            fw.write(item)
-            fw.write("\n")
+            if item.startswith("imgaug_"):
+                item = item.replace("\n", "").replace("\r\n", "")
+                fw.write(item)
+                fw.write("\n")
 
     print('time cost : %sS' % round(time.time() - t1, 2))
 
@@ -268,3 +352,8 @@ if __name__ == "__main__":
     aug_config = "./aug.yml"
     data_folder = "../../test/voc_eva_clothes_helmet"
     data_aug(aug_config, data_folder)
+
+    # IMG_DIR = data_folder + os.sep + "JPEGImages"
+    # XML_DIR = data_folder + os.sep + "Annotations"
+    # reset_dir(IMG_DIR)
+    # reset_dir(XML_DIR)
