@@ -10,8 +10,10 @@ import json
 import os
 import yaml
 import matplotlib.pyplot as plt
+from matplotlib.pyplot import MultipleLocator
 import xml.etree.ElementTree as ET
 from xml.etree.ElementTree import parse
+from tqdm import tqdm
 
 
 # 融合相关函数 ###########################################
@@ -562,7 +564,7 @@ def analysis_data(xml_file_path):
     boxes_size_h = []
     boxes_size_ratio = []
     names_xml = os.listdir(xml_file_path)
-    for name in names_xml:
+    for name in tqdm(names_xml):
         if name.endswith('.xml'):
             count += 1
             tree = ET.parse(xml_file_path + '/' + name)  # 打开xml文档
@@ -627,81 +629,109 @@ def analysis_data(xml_file_path):
     with open(results + '/labels_and_num.json', "w", encoding="utf-8") as fj:
         json.dump(objects_num, fj, ensure_ascii=False, indent=1)
 
-    # 散点图(图像) ###########################################
-    plt.figure(figsize=(40, 40))
-    plt.xlabel('Width', fontsize=50)
-    plt.ylabel('Height', fontsize=50)
-    plt.title('Images', fontsize=60)
-    plt.tick_params(labelsize=50)
+    dpi = 15
+    # 散点图(图像) ###########################################labelrotation=90
+    plt.figure(figsize=(80, 40))
+    plt.xlabel('Width', fontsize=80)
+    plt.ylabel('Height', fontsize=80)
+    plt.title('Images', fontsize=100)
+    plt.tick_params(which='both', direction='inout', pad=30, width=5, length=15, labelsize=50)
+    x_major_locator = MultipleLocator(500)
+    ax = plt.gca()
+    ax.xaxis.set_major_locator(x_major_locator)
     plt.scatter(images_size_w, images_size_h, c='r')
-    plt.savefig(results + '/images.png', dpi=300)
+    plt.savefig(results + '/images.png', dpi=dpi)
 
-    num_bins = 50  # 柱状条个数
     # 图像宽度分布
-    plt.figure(figsize=(40, 40))
-    plt.xlabel('Width', fontsize=50)
-    plt.ylabel('Number', fontsize=50)
-    plt.title('Distribution of Width about Images', fontsize=60)
-    plt.tick_params(labelsize=50)
+    num_bins = (max(images_size_w) - min(images_size_w)) // 200 + 1  # 柱状条个数
+    plt.figure(figsize=(80, 40))
+    plt.xlabel('Width', fontsize=80)
+    plt.ylabel('Number', fontsize=80)
+    plt.title('Distribution of Width about Images', fontsize=100)
+    plt.tick_params(which='both', direction='inout', pad=30, width=5, length=15, labelsize=50)
+    x_major_locator = MultipleLocator(200)
+    ax = plt.gca()
+    ax.xaxis.set_major_locator(x_major_locator)
     plt.hist(images_size_w, num_bins, facecolor='red', alpha=0.5)
-    plt.savefig(results + '/images_width.png', dpi=300)
+    plt.savefig(results + '/images_width.png', dpi=dpi)
 
     # 图像高度分布
-    plt.figure(figsize=(40, 40))
-    plt.xlabel('Height', fontsize=50)
-    plt.ylabel('Number', fontsize=50)
-    plt.title('Distribution of Height about Images', fontsize=60)
-    plt.tick_params(labelsize=50)
+    num_bins = (max(images_size_h) - min(images_size_h)) // 200 + 1  # 柱状条个数
+    plt.figure(figsize=(80, 40))
+    plt.xlabel('Height', fontsize=80)
+    plt.ylabel('Number', fontsize=80)
+    plt.title('Distribution of Height about Images', fontsize=100)
+    plt.tick_params(which='both', direction='inout', pad=30, width=5, length=15, labelsize=50)
+    x_major_locator = MultipleLocator(200)
+    ax = plt.gca()
+    ax.xaxis.set_major_locator(x_major_locator)
     plt.hist(images_size_h, num_bins, facecolor='red', alpha=0.5)
-    plt.savefig(results + '/images_height.png', dpi=300)
+    plt.savefig(results + '/images_height.png', dpi=dpi)
 
     # 图像高/宽比分布
-    plt.figure(figsize=(40, 40))
-    plt.xlabel('Height', fontsize=50)
-    plt.ylabel('Number', fontsize=50)
-    plt.title('Distribution of Ratio(Height/Width) about Images', fontsize=60)
-    plt.tick_params(labelsize=50)
+    num_bins = 20
+    plt.figure(figsize=(80, 40))
+    plt.xlabel('Height', fontsize=80)
+    plt.ylabel('Number', fontsize=80)
+    plt.title('Distribution of Ratio(Height/Width) about Images', fontsize=100)
+    plt.tick_params(which='both', direction='inout', pad=30, width=5, length=15, labelsize=50)
+    x_major_locator = MultipleLocator(0.1)
+    ax = plt.gca()
+    ax.xaxis.set_major_locator(x_major_locator)
     plt.hist(images_size_ratio, num_bins, facecolor='red', alpha=0.5)
-    plt.savefig(results + '/images_ratio.png', dpi=300)
+    plt.savefig(results + '/images_ratio.png', dpi=dpi)
 
     # 散点图(目标框) ##########################################
-    plt.figure(figsize=(40, 40))
-    plt.xlabel('Width', fontsize=50)
-    plt.ylabel('Height', fontsize=50)
-    plt.title('Boxes', fontsize=60)
-    plt.tick_params(labelsize=50)
+    plt.figure(figsize=(80, 40))
+    plt.xlabel('Width', fontsize=80)
+    plt.ylabel('Height', fontsize=80)
+    plt.title('Boxes', fontsize=100)
+    plt.tick_params(which='both', direction='inout', pad=30, width=5, length=15, labelsize=50)
+    x_major_locator = MultipleLocator(500)
+    ax = plt.gca()
+    ax.xaxis.set_major_locator(x_major_locator)
     plt.scatter(boxes_size_w, boxes_size_h, c='b')
-    plt.savefig(results + '/boxes.png', dpi=300)
+    plt.savefig(results + '/boxes.png', dpi=dpi)
 
-    num_bins = 50  # 柱状条个数
     # 目标框宽度分布
-    plt.figure(figsize=(40, 40))
-    plt.xlabel('Width', fontsize=50)
-    plt.ylabel('Number', fontsize=50)
-    plt.title('Distribution of Width about Boxes', fontsize=60)
-    plt.tick_params(labelsize=50)
+    num_bins = (max(boxes_size_w) - min(boxes_size_w)) // 200 + 1  # 柱状条个数
+    plt.figure(figsize=(80, 40))
+    plt.xlabel('Width', fontsize=80)
+    plt.ylabel('Number', fontsize=80)
+    plt.title('Distribution of Width about Boxes', fontsize=100)
+    plt.tick_params(which='both', direction='inout', pad=30, width=5, length=15, labelsize=50)
+    x_major_locator = MultipleLocator(200)
+    ax = plt.gca()
+    ax.xaxis.set_major_locator(x_major_locator)
     plt.hist(boxes_size_w, num_bins, facecolor='blue', alpha=0.5)
-    plt.savefig(results + '/boxes_width.png', dpi=300)
+    plt.savefig(results + '/boxes_width.png', dpi=dpi)
 
     # 目标框高度分布
-    plt.figure(figsize=(40, 40))
-    plt.xlabel('Height', fontsize=50)
-    plt.ylabel('Number', fontsize=50)
-    plt.title('Distribution of Height about Boxes', fontsize=60)
-    plt.tick_params(labelsize=50)
+    num_bins = (max(boxes_size_h) - min(boxes_size_h)) // 200 + 1  # 柱状条个数
+    plt.figure(figsize=(80, 40))
+    plt.xlabel('Height', fontsize=80)
+    plt.ylabel('Number', fontsize=80)
+    plt.title('Distribution of Height about Boxes', fontsize=100)
+    plt.tick_params(which='both', direction='inout', pad=30, width=5, length=15, labelsize=50)
+    x_major_locator = MultipleLocator(200)
+    ax = plt.gca()
+    ax.xaxis.set_major_locator(x_major_locator)
     plt.hist(boxes_size_h, num_bins, facecolor='blue', alpha=0.5)
-    plt.savefig(results + '/boxes_height.png', dpi=300)
+    plt.savefig(results + '/boxes_height.png', dpi=dpi)
 
     # 目标框高/宽比分布
-    plt.figure(figsize=(40, 40))
-    plt.xlabel('Height', fontsize=50)
-    plt.ylabel('Number', fontsize=50)
-    plt.title('Distribution of Ratio(Height/Width) about Boxes', fontsize=60)
-    plt.tick_params(labelsize=50)
+    num_bins = 30
+    plt.figure(figsize=(80, 40))
+    plt.xlabel('Height', fontsize=80)
+    plt.ylabel('Number', fontsize=80)
+    plt.title('Distribution of Ratio(Height/Width) about Boxes', fontsize=100)
+    plt.tick_params(which='both', direction='inout', pad=30, width=5, length=15, labelsize=50)
+    x_major_locator = MultipleLocator(0.4)
+    ax = plt.gca()
+    ax.xaxis.set_major_locator(x_major_locator)
     plt.hist(boxes_size_ratio, num_bins, facecolor='blue', alpha=0.5)
-    plt.savefig(results + '/boxes_ratio.png', dpi=300)
+    plt.savefig(results + '/boxes_ratio.png', dpi=dpi)
 
-    print('################################################################################')
     print('Have finished EDA process, the result is in dir: {} !'.format(results))
 
 
